==> haskell-toml-parser-1.3.1.3-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-toml-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 toml-parser
version:              1.3.1.3
visibility:           public
id:                   toml-parser-1.3.1.3-7H1wQ8BL5tw95aX3b40uyk
key:                  toml-parser-1.3.1.3-7H1wQ8BL5tw95aX3b40uyk
license:              ISC
copyright:            2023 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
synopsis:             TOML 1.0.0 parser
description:
    TOML parser using generated lexers and parsers with
    careful attention to the TOML 1.0.0 semantics for
    defining tables.

category:             Text
abi:                  d21273467081aed5b26d547f42206bb2
exposed:              True
exposed-modules:
    Toml Toml.FromValue Toml.FromValue.Generic Toml.FromValue.Matcher
    Toml.FromValue.ParseTable Toml.Lexer Toml.Lexer.Token Toml.Located
    Toml.Parser Toml.Parser.Types Toml.Position Toml.Pretty
    Toml.Semantics Toml.Semantics.Ordered Toml.ToValue
    Toml.ToValue.Generic Toml.Value

hidden-modules:       Toml.Lexer.Utils Toml.Parser.Utils
import-dirs:          /usr/lib/ghc-9.2.8/site-local/toml-parser-1.3.1.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/toml-parser-1.3.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-toml-parser
hs-libraries:         HStoml-parser-1.3.1.3-7H1wQ8BL5tw95aX3b40uyk
depends:
    array-0.5.4.0 base-4.16.4.0 containers-0.6.5.1
    prettyprinter-1.7.1-DLq7XLRLR0K7XkK6zjqNYU text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-toml-parser/html/toml-parser.haddock
haddock-html:         /usr/share/doc/haskell-toml-parser/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-toml-parser-1.3.1.3-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-toml-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 toml-parser
version:              1.3.1.3
visibility:           public
id:                   toml-parser-1.3.1.3-DXcb4YZ2Yb13YBUUjJfos2
key:                  toml-parser-1.3.1.3-DXcb4YZ2Yb13YBUUjJfos2
license:              ISC
copyright:            2023 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
synopsis:             TOML 1.0.0 parser
description:
    TOML parser using generated lexers and parsers with
    careful attention to the TOML 1.0.0 semantics for
    defining tables.

category:             Text
abi:                  63ff0271e4136d0db77691693654cef3
exposed:              True
exposed-modules:
    Toml Toml.FromValue Toml.FromValue.Generic Toml.FromValue.Matcher
    Toml.FromValue.ParseTable Toml.Lexer Toml.Lexer.Token Toml.Located
    Toml.Parser Toml.Parser.Types Toml.Position Toml.Pretty
    Toml.Semantics Toml.Semantics.Ordered Toml.ToValue
    Toml.ToValue.Generic Toml.Value

hidden-modules:       Toml.Lexer.Utils Toml.Parser.Utils
import-dirs:          /usr/lib/ghc-9.2.8/site-local/toml-parser-1.3.1.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/toml-parser-1.3.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-toml-parser
hs-libraries:         HStoml-parser-1.3.1.3-DXcb4YZ2Yb13YBUUjJfos2
depends:
    array-0.5.4.0 base-4.16.4.0 containers-0.6.5.1
    prettyprinter-1.7.1-JBjLrVgtbAKFzfFvIOg7Ri text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-toml-parser/html/toml-parser.haddock
haddock-html:         /usr/share/doc/haskell-toml-parser/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
